@@ -272,7 +272,7 @@ accept_command(char *cfgfile, char *addr, int port)
 		    }
 		    cfg = config_init();
                     /* reload template file */
-                    ret_reload = reload_tmpl(cfg->cf_templatepath);
+                    ret_reload = reload_tmpl(cfg);
 		    config_release(cfg);
                     if (ret_reload == 0) {
                         /* case reload successfull */
