@@ -968,6 +968,7 @@ encode_tmplheader(char **mail)
  *   char **          replaced date
  *   int              if mode is NOTICEPASS_FROM, in mailbody repalace <@@RCPTLIST@@> by *rcptinfo
  *                    if mode is NOTICEPASS_TO, in mailbody repalace <@@RCPTLIST@@> by *sender
+ *   char *           envfrom address
  *
  * Return:
  *   ERROR		-1   error
@@ -975,7 +976,7 @@ encode_tmplheader(char **mail)
  */
 int
 tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sender, char **retp, 
-                int mode)
+                int mode, char *envfrom)
 {
 
     int i;
@@ -1000,7 +1001,8 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
         {"PASSWORD", 8, NULL},
         {"RCPTLIST", 8, NULL},
         {"FILENAME", 8, NULL},
-        {"TOADDR", 6, NULL}
+        {"TOADDR", 6, NULL},
+        {"ENVFROM", 7, NULL}
     };
     tagnum = sizeof(tmpl_tag) / sizeof(struct strtag);
 
@@ -1028,6 +1030,9 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
     // set toaddr(sender address)
     tmpl_tag[TOADDR].st_str = sender;
 
+    // set envfrom(sender address)
+    tmpl_tag[ENVFROM].st_str = envfrom;
+
     // rcptaddr total length
     for (p = other; p != NULL; p = p->Next) {
         for (i = 0; (p->rcptlist + i)->rcpt_addr != NULL; i++) {
