@@ -207,10 +207,7 @@ search_rcptaddr(struct config *cfg, char *sender, struct rcptaddr *rcptlist, str
     struct search_res res;
 
     /* Initialization */
-    res.rcpt_dbp = NULL;
-    res.onetime_pass = NULL;
-    res.ld = NULL;
-    res.userdn = NULL;
+    memset(&res, 0, sizeof(res));
 
     /* make onetime password */
     ret = mk_passwd(&res.onetime_pass, pass_len);
@@ -346,10 +343,7 @@ search_rcptaddr_delmode(struct config *cfg, struct rcptaddr *rcptlist, struct rc
     struct search_res res;
 
     /* Initialization */
-    res.rcpt_dbp = NULL;
-    res.onetime_pass = NULL;
-    res.ld = NULL;
-    res.userdn = NULL;
+    memset(&res, 0, sizeof(res));
 
     /* make onetime password */
     ret = mk_passwd(&res.onetime_pass, pass_len);// res.onetime_pass = '\0' when pass_len = 0.
