@@ -395,11 +395,11 @@ passwd_parent(int fd[2], char *message)
 }
 
 int
-passwd_sendmail(struct config *cfg, char *rcpt, char *message)
+passwd_sendmail(struct config *cfg, char *rcpt, char *message, char *sender)
 {
     int		fd[2];
     int		ret;
-    int 	num;
+    int 	num, cnt, new_num;
     int 	i;
     char       **list = NULL;
     char       **arg_list = NULL;
@@ -422,7 +422,13 @@ passwd_sendmail(struct config *cfg, char *rcpt, char *message)
         return(SENDMAIL_FAILED);
     }
 
-    arg_list = (char **)malloc(sizeof(char *) * (num + 3));
+    /* passwordnoticesetsender is not set */
+    if (cfg->cf_passwordnoticesetsender == 0) {
+        cnt = 0;
+    } else {
+        cnt = 2;
+    }
+    arg_list = (char **)malloc(sizeof(char *) * (num + 3 + cnt));
 
     if (arg_list == NULL) {
         log(ERR_MEMORY_ALLOCATE, "passwd_sendmail", "arg_list", strerror(errno));
@@ -432,23 +438,51 @@ passwd_sendmail(struct config *cfg, char *rcpt, char *message)
         arg_list[i] = list[i];
     }
 
-    arg_list[num] = strdup("--");
-    if (arg_list[num] == NULL) {
+    new_num = num;
+
+    /* passwordnoticesetsender is seted */
+    if (cfg->cf_passwordnoticesetsender == 1) {
+    
+	arg_list[new_num] = strdup("-f");
+	if (arg_list[new_num] == NULL) {
+	    log(ERR_MEMORY_ALLOCATE, "passwd_sendmail", "arg_list", strerror(errno));
+	    arg_list_free(arg_list, new_num);
+	    free(list);
+	    return(SENDMAIL_FAILED);
+	}
+
+	new_num++;
+
+	arg_list[new_num] = strdup(sender);
+	if (arg_list[new_num] == NULL) {
+	    log(ERR_MEMORY_ALLOCATE, "passwd_sendmail", "arg_list", strerror(errno));
+	    arg_list_free(arg_list, new_num);
+	    free(list);
+	    return(SENDMAIL_FAILED);
+	}
+	new_num++;
+    }
+
+    arg_list[new_num] = strdup("--");
+    if (arg_list[new_num] == NULL) {
         log(ERR_MEMORY_ALLOCATE, "passwd_sendmail", "arg_list", strerror(errno));
-        arg_list_free(arg_list, num);
+        arg_list_free(arg_list, new_num);
         free(list);
         return(SENDMAIL_FAILED);
     }
 
-    arg_list[num + 1] = strdup(rcpt);
-    if (arg_list[num + 1] == NULL) {
+    new_num++;
+
+    arg_list[new_num] = strdup(rcpt);
+    if (arg_list[new_num] == NULL) {
         log(ERR_MEMORY_ALLOCATE, "passwd_sendmail", "arg_list", strerror(errno));
-        arg_list_free(arg_list, num + 1);
+        arg_list_free(arg_list, new_num);
         free(list);
         return(SENDMAIL_FAILED);
     }
 
-    arg_list[num + 2] = NULL;
+    new_num++;
+    arg_list[new_num] = NULL;
 
     /*
      * make pipe
@@ -458,7 +492,7 @@ passwd_sendmail(struct config *cfg, char *rcpt, char *message)
      */
     if (pipe(fd) == -1) {
 	log(ERR_PIPE_CREATE, "passwd_sendmail", strerror(errno));
-        arg_list_free(arg_list, num + 2);
+        arg_list_free(arg_list, new_num);
         free(list);
         return(SENDMAIL_FAILED);
     }
@@ -480,24 +514,24 @@ passwd_sendmail(struct config *cfg, char *rcpt, char *message)
             ret = WEXITSTATUS(sts);
 	    if (ret != 0) {
         	log(ERR_MAIL_SEND, "passwd_sendmail");
-                arg_list_free(arg_list, num + 2);
+                arg_list_free(arg_list, new_num);
 	        free(list);
         	return(SENDMAIL_FAILED);
 	    }
         } else {
 	    log(ERR_WAIT_CHILD, "passwd_sendmail", strerror(errno));
-            arg_list_free(arg_list, num + 2);
+            arg_list_free(arg_list, new_num);
             free(list);
             return(SENDMAIL_FAILED);
         }
     } else {
 	log(ERR_FORK_CREATE, "passwd_sendmail", strerror(errno));
-        arg_list_free(arg_list, num + 2);
+        arg_list_free(arg_list, new_num);
         free(list);
         return(SENDMAIL_FAILED);
     }
 
-    arg_list_free(arg_list, num + 2);
+    arg_list_free(arg_list, new_num);
     free(list);
     return(SENDMAIL_SUCCESS);
 }
