@@ -270,6 +270,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
     struct rcptinfo *p;
     int i, ret, chk_replace, chk_replace_noconv;
     char *temp = NULL, *notify_message, *rcptaddr, *confirmation_message;
+    struct noticepass_tmpl *top_noticepass_tmpl;
     char *org_p;
     struct rcptaddr *rdm_noext = NULL;
     struct rcptaddr *rdm_all = NULL;
@@ -341,7 +342,8 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
             if ((cfg->cf_fixedpassnotify[0] == 'Y' || cfg->cf_fixedpassnotify[0] == 'y')) {
                 org_p = p->passwd;	/* save original password */
                 p->passwd = cfg->cf_fixedpassnotifypass;
-	        temp = tmpl_init();
+	        top_noticepass_tmpl = tmpl_init();
+		temp = top_noticepass_tmpl->sender_tmpl;
 
 
 	        chk_replace = tmpl_tag_replace(temp, mz, p, from,
@@ -350,7 +352,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                 switch(chk_replace) {
                 case ERROR:
                     p->passwd = org_p;	/* restore original password */
-                    tmpl_release(temp);
+                    tmpl_release(top_noticepass_tmpl);
                     mailzip_clean(mz);
                     return ZIP_CONVERT_FAILED;
                 case CONVERT_ERROR:
@@ -360,13 +362,13 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                                                                  cfg->cf_errmsgtemplatepath, NOTICEPASS_FROM);
 
                     if (chk_replace_noconv == ERROR) {
-                        tmpl_release(temp);
+                        tmpl_release(top_noticepass_tmpl);
                         mailzip_clean(mz);
                         return ZIP_CONVERT_FAILED;
                     }
 	        }
                 p->passwd = org_p;	/* restore original password */
-	        tmpl_release(temp);
+	        tmpl_release(top_noticepass_tmpl);
 
                 // set header field "References"
                 if (strcmp(cfg->cf_references, "yes") == 0) {
@@ -522,13 +524,14 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
         tmp_rcptinfo.Next = NULL;
 
         /* パスワード通知メールの送信 */
-	temp = tmpl_init();
+	top_noticepass_tmpl = tmpl_init();
+	temp = top_noticepass_tmpl->sender_tmpl;
 
         chk_replace = tmpl_tag_replace(temp, mz, &tmp_rcptinfo, from, &notify_message, NOTICEPASS_FROM, from);
 
         switch(chk_replace) {
             case ERROR:
-                tmpl_release(temp);
+                tmpl_release(top_noticepass_tmpl);
                 mailzip_clean(mz);
                 free_rcptlist(rdm_all);
                 return ZIP_CONVERT_FAILED;
@@ -539,14 +542,14 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                                                              NOTICEPASS_FROM);
 
                 if (chk_replace_noconv == ERROR) {
-                    tmpl_release(temp);
+                    tmpl_release(top_noticepass_tmpl);
                     mailzip_clean(mz);
                     free_rcptlist(rdm_all);
                     return ZIP_CONVERT_FAILED;
                 }
         }
 
-	tmpl_release(temp);
+	tmpl_release(top_noticepass_tmpl);
 
         // set header field "references"
         if (strcmp(cfg->cf_references, "yes") == 0) {
@@ -601,12 +604,13 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                 /* if passwordnotice item set is 1 or 2 then send passwordnotice mail to TO */
                 if ((cfg->cf_passwordnotice == 1) || (cfg->cf_passwordnotice == 2)) {
                     /* make notify message */
-                    temp = tmpl_init();
+                    top_noticepass_tmpl = tmpl_init();
+		    temp = top_noticepass_tmpl->rcpt_tmpl;
                     chk_replace = tmpl_tag_replace(temp, mz, rdmpasslist, rcptaddr, &notify_message_to, NOTICEPASS_TO, from);
 
                     switch(chk_replace) {
                     case ERROR:
-                        tmpl_release(temp);
+                        tmpl_release(top_noticepass_tmpl);
                         mailzip_clean(mz);
                         return ZIP_CONVERT_FAILED;
                     case CONVERT_ERROR:
@@ -616,12 +620,12 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                                                                      NOTICEPASS_TO);
 
                         if (chk_replace_noconv == ERROR) {
-                            tmpl_release(temp);
+                            tmpl_release(top_noticepass_tmpl);
                             mailzip_clean(mz);
                             return ZIP_CONVERT_FAILED;
                         }
                     }
-                    tmpl_release(temp);
+                    tmpl_release(top_noticepass_tmpl);
 
                     /* send notify_password to TO */
                     if (passwd_sendmail(cfg, rcptaddr, notify_message_to, from) != 0) {
@@ -2144,6 +2148,7 @@ add_message(char *orig_msg, struct mailzip *mz,
     int ret;
     size_t olen = 0, tlen = 0, nlen = 0;
     int hflag;
+    char *tmpl_org = NULL;
 
     hflag = (strcasecmp(ctype->subtype, "html") == 0)?1:0;
 
@@ -2171,8 +2176,14 @@ add_message(char *orig_msg, struct mailzip *mz,
 
     // encode template
     if (charset == NULL) {
+        tmpl_org = tmpl;	    
         // case no charset force EN
         tmpl = (hflag == 0)?mz->am_tmpl->amt_en:mz->am_tmpl->amt_en_html;
+        if (tmpl == NULL) {
+            // case no EN template. Restore BOTH template
+            tmpl = tmpl_org;
+        }
+
         tmp_tmpl = strdup(tmpl);
         if (tmp_tmpl == NULL) {
 	    log(ERR_MEMORY_ALLOCATE, "add_message", "tmp_tmpl", strerror(errno));
